schemetools.SchemeVector
========================

.. inheritance-diagram:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector
   :private-bases:

.. autoclass:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.format

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__eq__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__repr__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__str__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`
